==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_entities/assetequipment_001/PositionDependency.java <==

package net.datastream.schemas.mp_entities.assetequipment_001;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ASSETPARENT_Type;
import net.datastream.schemas.mp_fields.POSITIONPARENT_Type;
import net.datastream.schemas.mp_fields.SYSTEMPARENT_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPENDENTPOSITION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NONDEPENDENTASSET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NONDEPENDENTPRIMARYSYSTEM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NONDEPENDENTSYSTEM" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "dependentposition",
    "nondependentasset",
    "nondependentprimarysystem",
    "nondependentsystem"
})
@XmlRootElement(name = "PositionDependency")
public class PositionDependency {

    @XmlElement(name = "DEPENDENTPOSITION", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected POSITIONPARENT_Type dependentposition;
    @XmlElement(name = "NONDEPENDENTASSET", namespace = "http://schemas.datastream.net/MP_fields")
    protected ASSETPARENT_Type nondependentasset;
    @XmlElement(name = "NONDEPENDENTPRIMARYSYSTEM", namespace = "http://schemas.datastream.net/MP_fields")
    protected SYSTEMPARENT_Type nondependentprimarysystem;
    @XmlElement(name = "NONDEPENDENTSYSTEM", namespace = "http://schemas.datastream.net/MP_fields")
    protected List<SYSTEMPARENT_Type> nondependentsystem;

    /**
     * Gets the value of the dependentposition property.
     * 
     * @return
     *     possible object is
     *     {@link POSITIONPARENT_Type }
     *     
     */
    public POSITIONPARENT_Type getDEPENDENTPOSITION() {
        return dependentposition;
    }

    /**
     * Sets the value of the dependentposition property.
     * 
     * @param value
     *     allowed object is
     *     {@link POSITIONPARENT_Type }
     *     
     */
    public void setDEPENDENTPOSITION(POSITIONPARENT_Type value) {
        this.dependentposition = value;
    }

    /**
     * Gets the value of the nondependentasset property.
     * 
     * @return
     *     possible object is
     *     {@link ASSETPARENT_Type }
     *     
     */
    public ASSETPARENT_Type getNONDEPENDENTASSET() {
        return nondependentasset;
    }

    /**
     * Sets the value of the nondependentasset property.
     * 
     * @param value
     *     allowed object is
     *     {@link ASSETPARENT_Type }
     *     
     */
    public void setNONDEPENDENTASSET(ASSETPARENT_Type value) {
        this.nondependentasset = value;
    }

    /**
     * Gets the value of the nondependentprimarysystem property.
     * 
     * @return
     *     possible object is
     *     {@link SYSTEMPARENT_Type }
     *     
     */
    public SYSTEMPARENT_Type getNONDEPENDENTPRIMARYSYSTEM() {
        return nondependentprimarysystem;
    }

    /**
     * Sets the value of the nondependentprimarysystem property.
     * 
     * @param value
     *     allowed object is
     *     {@link SYSTEMPARENT_Type }
     *     
     */
    public void setNONDEPENDENTPRIMARYSYSTEM(SYSTEMPARENT_Type value) {
        this.nondependentprimarysystem = value;
    }

    /**
     * Gets the value of the nondependentsystem property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the nondependentsystem property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNONDEPENDENTSYSTEM().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link SYSTEMPARENT_Type }
     * 
     * 
     */
    public List<SYSTEMPARENT_Type> getNONDEPENDENTSYSTEM() {
        if (nondependentsystem == null) {
            nondependentsystem = new ArrayList<SYSTEMPARENT_Type>();
        }
        return this.nondependentsystem;
    }

}

==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_entities/assetequipment_001/PositionDependency.java <==

package net.datastream.schemas.mp_entities.assetequipment_001;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ASSETPARENT_Type;
import net.datastream.schemas.mp_fields.POSITIONPARENT_Type;
import net.datastream.schemas.mp_fields.SYSTEMPARENT_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPENDENTPOSITION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NONDEPENDENTASSET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NONDEPENDENTPRIMARYSYSTEM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NONDEPENDENTSYSTEM" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "dependentposition",
    "nondependentasset",
    "nondependentprimarysystem",
    "nondependentsystem"
})
@XmlRootElement(name = "PositionDependency")
public class PositionDependency {

    @XmlElement(name = "DEPENDENTPOSITION", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected POSITIONPARENT_Type dependentposition;
    @XmlElement(name = "NONDEPENDENTASSET", namespace = "http://schemas.datastream.net/MP_fields")
    protected ASSETPARENT_Type nondependentasset;
    @XmlElement(name = "NONDEPENDENTPRIMARYSYSTEM", namespace = "http://schemas.datastream.net/MP_fields")
    protected SYSTEMPARENT_Type nondependentprimarysystem;
    @XmlElement(name = "NONDEPENDENTSYSTEM", namespace = "http://schemas.datastream.net/MP_fields")
    protected List<SYSTEMPARENT_Type> nondependentsystem;

    /**
     * Obtient la valeur de la propriété dependentposition.
     * 
     * @return
     *     possible object is
     *     {@link POSITIONPARENT_Type }
     *     
     */
    public POSITIONPARENT_Type getDEPENDENTPOSITION() {
        return dependentposition;
    }

    /**
     * Définit la valeur de la propriété dependentposition.
     * 
     * @param value
     *     allowed object is
     *     {@link POSITIONPARENT_Type }
     *     
     */
    public void setDEPENDENTPOSITION(POSITIONPARENT_Type value) {
        this.dependentposition = value;
    }

    /**
     * Obtient la valeur de la propriété nondependentasset.
     * 
     * @return
     *     possible object is
     *     {@link ASSETPARENT_Type }
     *     
     */
    public ASSETPARENT_Type getNONDEPENDENTASSET() {
        return nondependentasset;
    }

    /**
     * Définit la valeur de la propriété nondependentasset.
     * 
     * @param value
     *     allowed object is
     *     {@link ASSETPARENT_Type }
     *     
     */
    public void setNONDEPENDENTASSET(ASSETPARENT_Type value) {
        this.nondependentasset = value;
    }

    /**
     * Obtient la valeur de la propriété nondependentprimarysystem.
     * 
     * @return
     *     possible object is
     *     {@link SYSTEMPARENT_Type }
     *     
     */
    public SYSTEMPARENT_Type getNONDEPENDENTPRIMARYSYSTEM() {
        return nondependentprimarysystem;
    }

    /**
     * Définit la valeur de la propriété nondependentprimarysystem.
     * 
     * @param value
     *     allowed object is
     *     {@link SYSTEMPARENT_Type }
     *     
     */
    public void setNONDEPENDENTPRIMARYSYSTEM(SYSTEMPARENT_Type value) {
        this.nondependentprimarysystem = value;
    }

    /**
     * Gets the value of the nondependentsystem property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the nondependentsystem property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNONDEPENDENTSYSTEM().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link SYSTEMPARENT_Type }
     * 
     * 
     */
    public List<SYSTEMPARENT_Type> getNONDEPENDENTSYSTEM() {
        if (nondependentsystem == null) {
            nondependentsystem = new ArrayList<SYSTEMPARENT_Type>();
        }
        return this.nondependentsystem;
    }

}
